@@ -14,7 +14,7 @@
 #include "dviInt.h"
 
 #ifndef lint
-static char rcsid[] VAR_UNUSED = "$Id: fontPK.c,v 1.2 1999/06/15 16:18:59 lingnau Exp $";
+static char rcsid[] VAR_UNUSED = "$Id: fontPK.c,v 1.3 2000/05/18 12:50:32 lingnau Exp $";
 #endif /* lint */
 
 typedef struct PkCharInfo {
@@ -146,7 +146,7 @@ MakeInfo (dviFont)
 			: ((((b3)*z)/256+(b2)*z)/256+(b1)*z)/beta - alpha ) \
 		: ((((b3)*z)/256+(b2)*z)/256+(b1)*z)/beta )
 
-    if ((infoPtr = ckalloc(sizeof(PkInfo))) == (PkInfo *)0) {
+    if ((infoPtr = (PkInfo *)ckalloc(sizeof(PkInfo))) == (PkInfo *)0) {
 	return (PkInfo *)0;
     }
 
@@ -228,7 +228,8 @@ MakeInfo (dviFont)
 	}
     }
 
-    charInfoPtr = ckalloc((maxChar - minChar + 1) * sizeof(PkCharInfo));
+    charInfoPtr = (PkCharInfo *)ckalloc((maxChar - minChar + 1)
+					* sizeof(PkCharInfo));
     if (charInfoPtr == (PkCharInfo *)0) {
 	ckfree((char *)infoPtr);
 	return (PkInfo *)0;
@@ -420,7 +421,7 @@ GlyphHeader(codePtr, newCodePtrPtr)
     *newCodePtrPtr = codePtr;
 
     size = sizeof(Dvi_Glyph) + RoundUp8(width) * height;
-    glyphPtr = ckalloc(size);
+    glyphPtr = (Dvi_Glyph *)ckalloc(size);
     memset(glyphPtr, 0, size);
     glyphPtr->width = width, glyphPtr->height = height;
     glyphPtr->bytesWidth = RoundUp8(width);
